function [out1, out2]=curveintersection(xvec1,yvec1,xvec2,yvec2,varargin)
%[out1, out2]=CURVEINTERSECTION(xvec1,yvec1,xvec2,yvec2)
%
%Given two 2D-curves, specified by [xvec1,yvec1] and [xvec2,yvec2]
%respectively - curveintersection calculates the decimal index of the
%first intersection point, for the first and the second curve
%respectively. If there is no intersection - empty indexes are returned

default={
    'trivialmode','off';  %If either of the vectors
                          %xvec1,yvec1,xvec2,yvec2 are constant - or
                          %almost constant (see errormargin) - one can
                          %speed up the process of finding the
                          %intersection points considerably 
    'errormargin',1e-2
    };
eval(setvalues)


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% For trivialmode 'on' %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if isequal(trivialmode,'on')
    temp1x=max(xvec1)-min(xvec1);
    temp2x=max(xvec2)-min(xvec2);
    temp1y=max(yvec1)-min(yvec1);
    temp2y=max(yvec2)-min(yvec2);
    
    if temp1x<=min([temp2x temp1y temp2y]) & temp1x<errormargin
	temp=(max(xvec1)+min(xvec1))*0.5;
	i=decimalindex(temp,xvec2);
	out2=i;
	tempp=findvalue(temp,xvec2,yvec2);
	ii=decimalindex(tempp,yvec1);
	out1=ii;
	return
    end
    
    %The below stuff is just copied and permuted x<->y and 1<->2
    
    if temp1y<=min([temp2y temp1x temp2x]) & temp1y<errormargin
	temp=(max(yvec1)+min(yvec1))*0.5;
	i=decimalindex(temp,yvec2);
	out2=i;
	tempp=findvalue(temp,yvec2,xvec2);
	ii=decimalindex(tempp,xvec1);
	out1=ii;
	return
    end
    
    if temp2y<=min([temp1y temp2x temp1x]) & temp2y<errormargin
	temp=(max(yvec2)+min(yvec2))*0.5;
	i=decimalindex(temp,yvec1);
	out1=i;
	tempp=findvalue(temp,yvec1,xvec1);
	ii=decimalindex(tempp,xvec2);
	out2=ii;
	return
    end
    
    if temp2x<=min([temp1x temp2y temp1y]) & temp2x<errormargin
	temp=(max(xvec2)+min(xvec2))*0.5;
	i=decimalindex(temp,xvec1);
	out1=i;
	tempp=findvalue(temp,xvec1,yvec1);
	ii=decimalindex(tempp,yvec2);
	out2=ii;
	return	
    end
    
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% For trivialmode 'off' %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


happened=0;
for i=1:length(xvec1)-1;
    for j=1:length(xvec2)-1;

        pos1a=[xvec1(i)   yvec1(i)];
	pos1b=[xvec1(i+1) yvec1(i+1)];
	pos2a=[xvec2(j)   yvec2(j)];
	pos2b=[xvec2(j+1) yvec2(j+1)];
	[h1, h2]=intersection(pos1a,pos1b,pos2a,pos2b);
	if isempty(h1)
	    %Do nothing
	else
	    happened=1;
	    decindex1=i+h1;
	    decindex2=j+h2;
	    break
	end
    end    
    
    if happened==1
	break
    end
end

if happened==1
    out1=decindex1;
    out2=decindex2;
else
    out1=[];
    out2=[];
end



