function [outx, outy]=cutthecrap(xbase,ybase,x,y)
%CUTTHECRAP(xbase,ybase,x,y)
% Given a 2D-line represented by an x-vector and a y-vector
% Cutthecrap removes the part of this lines that lies outside of the box
% specified by xbase and ybase.

%% Making sure that x is a column vector %%%%

xcon=1;
if size(x,2)>1
    x=x';
    xcon=1;
end

ycon=1;
if size(y,2)>1
    y=y';
    ycon=1;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%% Finding the first set of points, counted from the start of x and
%%%%%%%%% y that are entireley inside the boundaries.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

xb1=min(xbase);
xb2=max(xbase);
yb1=min(ybase);
yb2=max(ybase);

inflag1=0;
for i=1:length(x);              %Find the first point within the borders
    if inside(x(i),y(i),[xb1 xb2],[yb1 yb2]);
        inflag1=1;
        break
    end
end

if i==length(x) & inflag1==0    %Return if nothing is inside
    outx=[];
    outy=[];
    return
end

inflag2=1;                      %Find the last point within the borders
for j=i+1:length(x);
    if ~inside(x(j),y(j),[xb1 xb2],[yb1 yb2]);
        inflag2=0;
        break
    end
end

%%% Finding an interpolated starting point if necessary %%%%%%%%%%%%%

if i==1
    xstart=[];
    ystart=[];
else
    outpoint=[x(i-1) y(i-1)];
    inpoint=[x(i) y(i)];
    extra=borderpoint(inpoint,outpoint,xb1,xb2,yb1,yb2);
    xstart=extra(1);
    ystart=extra(2);
end

%%% Finding an interpolated final point if necessary %%%%%%%%%%%%%

if j==length(x) & inflag2==1  %If last given point is within
    xend=x(j);
    yend=y(j);
else
    outpoint=[x(j) y(j)];
    inpoint=[x(j-1) y(j-1)];
    extra=borderpoint(inpoint,outpoint,xb1,xb2,yb1,yb2);
    xend=extra(1);
    yend=extra(2);
end

%%%%% Output %%%%%%%%%%%%%%%%%%%%%%%

x=[xstart;x(i:j-1);xend];
y=[ystart;y(i:j-1);yend];

le=length(x);
order=max(x)-min(x)+max(y)-min(y);
if ~isempty(xend)
    if norm([xend-x(le-1),yend-y(le-1)])/order<1e-14;
        x=x(1:le-1);
        y=y(1:le-1);
    end
end

if ~isempty(xstart)
    if norm([xstart-x(le-1),ystart-y(le-1)])/order<1e-14;
        x=x(2:length(x));
        y=y(2:length(x));
    end
end

if xcon==1
    outx=x';
end

if ycon==1
    outy=y';
end

%%%%%% The inside function %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function out=inside(x,y,xrange,yrange)

if x>xrange(1) & x<xrange(2) & y>yrange(1) & y<yrange(2)
    out=1;
else
    out=0;
end

%%%%%% The borderpoint function %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%% Finds the intersectionpoint between a point inside the range and a
%%%%%% point outside the range

function out=borderpoint(inpoint,outpoint,xb1,xb2,yb1,yb2)

delta=outpoint-inpoint;
if outpoint(1)<xb1
    delta=delta*abs(   (xb1-inpoint(1))/delta(1)   );
    outpoint=inpoint+delta;
end
if outpoint(1)>xb2
    delta=delta*abs(   (xb2-inpoint(1))/delta(1)   );
    outpoint=inpoint+delta;
end
if outpoint(2)<yb1
    delta=delta*abs(   (yb1-inpoint(2))/delta(2)   );
    outpoint=inpoint+delta;
end
if outpoint(2)>yb2
    delta=delta*abs(   (yb2-inpoint(2))/delta(2)   );
    outpoint=inpoint+delta;
end
out=outpoint;















