function [X,Y,Z,tbase,xbase,rotset,h]=embedit(metricstring,xinterval,eyeset,varargin)
%EMBEDIT(metricstring,xinterval,eyeset,OPTIONS)
%
%Assuming a diagonalized two-dimensional, timeindependent, positive definite metric, where
%g00, g11 and g00' are all given through the function specified by 'metricstring' -
%this function then embeds the metric as a rotational surface.

default={
    'scale',    1;
    'offset',   [0 0 0];
    'mode',     1;
    'rotangle', 0;
    'col', [0 0.7 0];
    'linecol', [0 0 0];
	};

eval(setvalues);

%%%% Setting up an x-vector with roughly constant proper distance

ds=(max(xinterval)-min(xinterval))/100;
x=zeros(1,10000);        %Initializing
x(1)=min(xinterval);
i=1;
while x(i)<max(xinterval)
    [a,c,aprim]=eval([metricstring '(x(i))']);
    i=i+1;
    x(i)=ds/sqrt(c)+x(i-1);
end
x=[x(1:i) max(xinterval)];
[a,c,aprim]=eval([metricstring '(x)']);

%%%% Setting up the rotational surface %%%%%%%%%%%%%%%%%%%

temp=max(aprim.^2./(4*c.*a));
k=0.99*1/sqrt(temp);
%k=0.99*sqrt(min(4*c.*a./aprim.^2));    %Auto maximization

r=k*sqrt(a);
dzdx=sqrt(c-k^2*aprim.^2/4./a);
z=cumtrapz(x,dzdx);
cc=ones(size(z));

az=eyeset{1};
el=eyeset{2};
radius=eyeset{3};
cell=rjxrotsurf(r',z',cc','mode',mode,'setlines','on','az',az,'el',el,'radius',radius,...
		'linesep1',16*3,'linesep2',4,'getsurf','on','reverse','on','rotangle',rotangle,...
		'epsilon',0.01,'col',col,'Nphi',120,'linecol',linecol);

%%%% Outputting information %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

xbase=x;
h=cell{1};
X=cell{2};
Y=cell{3};
Z=cell{4};
phi=cell{5};
tbase=phi*k;
rotset={r,z};








