function out=findline(X,Y,Z,xbase,ybase,x,y,generatorstring,varargin)
%FINDLINE(X,Y,Z,xbase,ybase,x,y,generatorstring,varargin)
%
% Given a surface characterized be X,Y,Z, basevectors (for the coordinate
% mapping of the surface) xbase and ybas, and a starting position x,y -
% findline integrates forward to find a line that is at a given angle to
% the generator (absolute scheme of spacetime visualizations)
% everywhere. Works to find generator worldlines, lines perpendicular to the
% generators, photons etc. If the generators are trivial so that they are
% always directed along one of the coordinate directions of the matrixes - 
% try generatorstring='standardgenerator1' or 'standardgenerator2' or 
% 'standardgenerator3' or 'standardgenerator4'.

default={
    'steplength',0.01;
    'maxlength',1;
    'langle',0;           %0,45,-45,90,-90 typically
    'number',[];
    'checkflag',[];
    'lockorigin','off';    %Keeps the settings at the origin for metric
                           %and generators
    'lockpoint',[];        %If non empty, at what point to evaluate
                           %gendir and the metric for lockorigin.
    'xclosed','off';       %Circular boundary 'on', 'off'
    'yclosed','off';       %Circular boundary 'on', 'off'
    'fixdir',[];           %If non-zero it overrules the generator
                           %function for gendir and locks the origin.
	};
eval(setvalues)

if ~isempty(number)
    steplength=maxlength/number;
end

imax=floor(maxlength/steplength);
reststeplength=maxlength-imax*steplength;
if isequal(reststeplength,0)
    reststeplength=steplength;
    imax=imax-1;
end

xvec=zeros(1,imax+1);
yvec=zeros(1,imax+1);
xvec(1)=x;
yvec(1)=y;
radangle=langle/180*pi;

%%%%% Evaluation at the start - for lockorigin %%%%%%

gendir=eval([generatorstring '(x,y)']);
[guu guv gvv]=getmetric(X,Y,Z,xbase,ybase,x,y);

if isempty(lockpoint)
    gendir=eval([generatorstring '(x,y)']);
    [guu guv gvv]=getmetric(X,Y,Z,xbase,ybase,x,y);
else
    gendir=eval([generatorstring '(lockpoint(1),lockpoint(2))']);
    [guu guv gvv]=getmetric(X,Y,Z,xbase,ybase,lockpoint(1),lockpoint(2));
end

if ~isempty(fixdir)
    lockorigin='on';
    gendir=fixdir;
end

%%%% Looping forward in proper steps %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for i=2:imax+1
    
    if min(xbase)>x | max(xbase)<x | min(ybase)>y | max(ybase)<y
	disp('Line outside surface, returning the line so far');
	[xcut,ycut]=cutthecrap(xbase,ybase,xvec(1:i-1),yvec(1:i-1));
	out={xcut,ycut};
	%out={xvec(1:i-1),yvec(1:i-1)};
	return
    end
    
    if i>imax
	steplength=reststeplength;
    end
    
    if ~isequal(lockorigin,'on')   %Then update the metric and the generators
	gendir=eval([generatorstring '(x,y)']);
	[guu guv gvv]=getmetric(X,Y,Z,xbase,ybase,x,y);
    end
	
    dx1=gendir(1);  %Temporary
    dy1=gendir(2);  %Temporary
    
    [dxort,dyort]=orthogonalvector(dx1,dy1,guu,guv,gvv);
    dx2=dx1*cos(radangle)+dxort*sin(radangle); 
    dy2=dy1*cos(radangle)+dyort*sin(radangle); 
    
    dstype=sqrt(guu*dx2^2+2*guv*dx2*dy2+gvv*dy2^2);
    dx=dx2/dstype*steplength;
    dy=dy2/dstype*steplength;
    x=x+dx;
    y=y+dy;
    
    if isequal(xclosed,'on')
	x=rjclosed(x,xbase);
    end
    
    if isequal(yclosed,'on')
	y=rjclosed(y,ybase);
    end
    
    xvec(i)=x;
    yvec(i)=y;
end

out={xvec,yvec};















