function out=findphoton(rvec,zvec,a_base,phi_base,a_start,phi_start,mode,maxlength,number)
%
%FINDPHOTON(rvec,zvec,a_base,phi_base,a_start,phi_start,mode,maxlength,number)
%
%  Assuming a simple rotational surface, where the generators of the absolute metric are either 
%  directed along or around the surface, this function finds trajectories that are always
%  at 45 degrees to a purely azimuthal line, i.e the photons.
%
%  rvec is a vector with the embedding radius
%  zvec is a vector with the distance as measured along the symmetry axis
%  a_base is the base vector for the coordinate running along the surface
%  phi_base is the base vector corresponding to the azimuthal angle round the surface
%  a_start is the starting point in the coordinate along the surface
%  phi_start is the starting point in the azimuthal angle 
%  mode takes the values 1,2,3 or 4 and decides in which of the four directions to go
%  maxlength is measure of how long to go, along the surface. The proper length is 1.41 times this
%  number is the wanted number of trajectory segment, if empty the facetsize of the rotational surface is used
%                                                     to determine the step length
%
%  out={phi_vec,a_vec}: phivec is the azimuthal vector for the trajectory and a_vec is the coordinate-along
%  the-surface vector for the trajectory.



lr=length(rvec);
dr=rvec(2:lr)-rvec(1:lr-1);
dz=zvec(2:lr)-zvec(1:lr-1);
dl=sqrt(dr.^2+dz.^2);
if size(dl,2)>size(dl,1)
     l_base=[0 cumsum(dl)];
else
     l_base=[0;cumsum(dl)];
end

l_start=findvalue(a_start,a_base,l_base);

if isempty(number)
     startindex=floor(decimalindex(a_start,a_base));
     deltaltemp=dl(startindex)/2;
     N=floor(maxlength/(deltaltemp));
     deltal=maxlength/N;
else
     N=number;
     deltal=maxlength/N;    
end

if mode==1;deltal=deltal;k=1;end
if mode==2;deltal=deltal;k=-1;end
if mode==3;deltal=-deltal;k=-1;end
if mode==4;deltal=-deltal;k=1;end

lphoton=linspace(l_start,l_start+N*deltal,N+1);
a_vec=a_start;
phi_vec=phi_start;
phi=phi_start;


for i=2:length(lphoton)
     l=lphoton(i);
     r=findvalue(l,l_base,rvec);
     deltaphi=k*abs(deltal)/r;
     phi=phi+deltaphi;
     phi_vec=[phi_vec phi];
     a=findvalue(l,l_base,a_base);
     a_vec=[a_vec a];
end

out={phi_vec,a_vec};











