function [out1, out2]=intersection(vec1a,vec1b,vec2a,vec2b)
%INTERSECTION(vec1a,vec1b,vec2a,vec2b)
%
%Given two 2D, straight line segments (denoted 1 and 2), specified by their
%start (a) and end (b) vectors - intersection calculates if the two line
%segments are intersecting each other. If they do intersect - the
%distance to the intersection point relative the total distance of the
%segments is returned (as mesured from each vectors starting point (a)),
%for both segments respectively. If they do not intersect two empty matrixes are returned.

vec1=vec1b-vec1a;
vec2=vec2b-vec2a;
basevec=vec2a-vec1a;
if isequal(norm(vec1),0) | isequal(norm(vec2),0)
    %error('RJ: zero length vector, returning no intersection')
    disp('RJ: zero length vector, returning no intersection')
    out1=[];
    out2=[];
    return;
end
    
angle1=acos(sum(vec1.*basevec)/norm(vec1)/norm(basevec));
angle2=acos(sum(vec2.*basevec)/norm(vec2)/norm(basevec));
angleopposite1=(pi-angle2);
angleopposite2=angle1;
temp=cross([0 0 1],[basevec 0]);
ortbasevec=temp(1:2);

dir1=sum(vec1.*ortbasevec);
dir2=sum(vec2.*ortbasevec);
angleoppositebase=angle2-angle1;

if sign(dir1)==sign(dir2) & angleoppositebase>0 
    factor=sin(angleoppositebase)/norm(basevec);
    length1=sin(angleopposite1)/factor;
    length2=sin(angleopposite2)/factor;
    out1=length1/norm(vec1);
    out2=length2/norm(vec2);
    if out1>1 | out2>1
	out1=[];
	out2=[];
    end
else
    out1=[];
    out2=[];
end

if out1<0 | out2<0;
    disp('RJ:Problem with intersection.m')
end

out1;
out2;

