function out=minkowski(X,Y,Z,xbase,ybase,eyeset,xvec1,yvec1,xvec2,yvec2,varargin)
%MINKOWSKI(X,Y,Z,xbase,ybase,eyeset,xvec1,yvec1,xvec2,yvec2,varargin)
%
% Notice that there is an update - rjxminkowski
%
% X,Y,Z are the matrixes describing the surface where to put the
% minkowski system. xbase and ybase are the coordinate base vectors for
% the surface. xvec1 and yvec2 are the coordinate vectors of the main
% time arrow of the minkowski system. If this corresponds to a longer
% vector in space than that specified by msize, the vector will be cut to
% the proper length. If it is shorter - the vector will be extended to
% the proper length. xvec2 and yvec2 are the coordinate vectors of the
% local x-axis of the Minkowski system. The same proper length arguments aplies
% also to this vector. If xvec2 and yvec2 are left empty ([]) they are
% calculated to be proper orthogonal to the time axis - and to be
% coordinate straight. The default values of the options specified in varargin are given by:
%
%default={
%    'setlightcone', 'on';      %'on' or 'off'
%    'msize',0.2;            %The proper size of the system
%    'arrowcol', [1 0 1];
%    'lightconecol', [1 1 0];
%    'transparency', 0.8;   %Transparency of the light cone
%    'leftright','on';
%    'mode',1;
%    'extraort',{}          %The Left-orthogonal axis {tvec,xvec}.
%    'epsilon',0.3;
% };

default={
    'setlightcone', 'on';      %'on' or 'off'
    'msize',0.2;            %The proper size of the system
    'arrowcol', [1 0 1];
    'lightconecol', [1 1 0];
    'transparency', 0.8;   %Transparency of the light cone
    'leftright','on';
    'mode',1;
    'extraort',{}          %The Left-orthogonal axis {tvec,xvec}.
    'epsilon',0.3;
 };

eval(setvalues);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

hold on

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if isempty(xvec2) | isempty(yvec2)
    dx=xvec1(length(xvec1))-xvec1(1);
    dy=yvec1(length(yvec1))-yvec1(1);
    [guu guv gvv]=getmetric(X,Y,Z,xbase,ybase,xvec1(1),yvec1(1));
    [dxort,dyort]=orthogonalvector(dx,dy,guu,guv,gvv);
    xvec2=linspace(xvec1(1),xvec1(1)+dxort,length(xvec1));
    yvec2=linspace(yvec1(1),yvec1(1)+dyort,length(yvec1));
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

cutlength=msize;
lightconefactor=0.75;
width=0.08*msize;
if isequal(leftright,'on')  %Decreasing the length of the spatial axes if
                            %leftright is on
    spacefactor=lightconefactor;
else
    spacefactor=1;
end

%%% if length xvec=0  and dir =/0  make linearization .....

thcd={};
thcd{length(thcd)+1}={'surfline',xvec1,yvec1,'epsilon',epsilon,'cutlength',msize,...
		    'arrow','curved','width',width,'col',arrowcol,'backextend',width/2};

if isequal(setlightcone,'on')
thcd{length(thcd)+1}={'surfline',xvec1,yvec1,'epsilon',epsilon*5/3,'cutlength',...
		    msize*lightconefactor,'arrow','off','startwidth',0, ...
		    'endwidth',2*msize*lightconefactor,'col', ...
		    lightconecol};
end

thcd{length(thcd)+1}={'surfline',xvec2,yvec2,'epsilon',epsilon,...
		    'cutlength',msize*spacefactor,'width',width,...
		    'arrow','curved','col',arrowcol,'backextend',width/2};

if isequal(leftright,'on')
    if isempty(extraort)
	thcd{length(thcd)+1}={'surfline',2*xvec2(1)-xvec2,2*yvec2(1)-yvec2,'epsilon',epsilon,...
		    'cutlength',msize*spacefactor,'width',width,'arrow','curved',...
		    'col',arrowcol,'backextend',width/2};
    else
	thcd{length(thcd)+1}={'surfline',extraort{1},extraort{2},'epsilon',epsilon,...
		    'cutlength',msize*spacefactor,'width',width,'arrow','curved',...
		    'col',arrowcol,'backextend',width/2};
    end
    
end

h=putonsurf(X,Y,Z,xbase,ybase,eyeset,thcd,'edgecut','on','mode',mode);
set(h(2),'FaceAlpha',transparency)



















