function out=rjxplot3(A,B,C,linestyle,varargin)
% RJXPLOT(X,Y,Z,linestring,Options)
%
% Works like PLOT3 but with options, default:
%
%     'scale',    1;
%     'offset',   [0 0 0];
%     'mode',     1;
%     'az',       []
%     'el',       [];
%     'radius',   [];     
%     'epsilon',  0.01;
%
% It is quite analogous to RJXSURF.

% The default values

default={
    'scale',    1;
    'offset',   [0 0 0];
    'mode',     1;
    'az',       []
    'el',       [];
    'radius',   [];     
    'epsilon',  0.001;
    'farg',    [];
    'col', [];
    'toplot3',{};
    'eyeset', [];       %{az,el,radius}
};

if nargin-length(varargin)~=4
    error('RJ:you must specify X,Y,Z and ''linestyle'' ')
end

if rem(length(varargin),2)==1,
   error('RJ: Property value pairs expected.')
end  

eval(setvalues)

if ~isempty(col)
    farg=col;
end

if ~isempty(eyeset)
    az=eyeset{1};
    el=eyeset{2};
    radius=eyeset{3};
end

%%%%%%%% The real stuff starts here %%%%%%%%%%%%%%%%%%%%%%%%%

if isequal(radius,Inf) 
    radius=[];
end

X=scale*A+offset(1);
Y=scale*B+offset(2);
Z=scale*C+offset(3);

if mode~=1
[X Y Z]=rjpermute(X,Y,Z,mode);
end

el=el/180*pi;
az=az/180*pi;

norm=[cos(el)*sin(az) -cos(el)*cos(az) sin(el)];  %az is zero at the negative y-axis

if ~isempty(radius)
    r0=radius*norm;
end

if isempty(radius)
    if isempty(az) | isempty(el)
        %Do nothing to X,Y and Z
    else
        v=epsilon*norm;
        X=X+v(1);
        Y=Y+v(2);
        Z=Z+v(3);
    end       
else
    if isempty(az) | isempty(el)
        error('RJ: You must specify the angles ''az'' and ''el'' when you give a ''radius''.')
    end
        DX=r0(1)-X;
        DY=r0(2)-Y;
        DZ=r0(3)-Z;
        DR=sqrt(DX.^2+DY.^2+DZ.^2);
        DXnorm=DX./DR;
        DYnorm=DY./DR;
        DZnorm=DZ./DR;
        X=X+DXnorm*epsilon;
        Y=Y+DYnorm*epsilon;
        Z=Z+DZnorm*epsilon;
end

if ~isempty(farg)
    out=plot3(X,Y,Z,linestyle,'Color',farg,toplot3{:});
else
    out=plot3(X,Y,Z,linestyle,toplot3{:});
end

%The latter alternative is there to enable lifting of the points 
%towards the eye when using perspective viewing - usable
%for many spacetime hat applications :)

