function out=rjxsurfcross(x,normal,up,varargin)
%RJXCROSS(X,N,Options)
%
% default={
%     'farg',     [0 0 0];
%     'scale',    1;
%     'offset',   [0 0 0];
%     'mode',     1;
%     'az',       []
%     'el',       [];
%     'radius',   [];     
%     'epsilon',  0.01;
%     'width',0.04;
%     'thickness', 0.01;
%     'perpmode',  'off';

default={
    'farg',     [0 0 0];
    'scale',    1;
    'offset',   [0 0 0];
    'mode',     1;
    'az',       []
    'el',       [];
    'radius',   [];     
    'epsilon',  0.01;
    'width',0.03;
    'thickness', 0.005;
    'thick',[];              %Overrules thickness
    'crosstype',  'plus';
    'reflectionproperties',[];
    'col', [];               %Overrules 'farg'
};

if rem(length(varargin),2)==1
   error('RJ: Property value pairs expected.')
end

if ( nargin-length(varargin) )~=3
   error('RJ: You must specify x, normal and up-vector (to determine the rotation of the cross).')
end

eval(setvalues)

to_rjxsurf={'scale',scale,'offset',offset,'mode',mode, ...
        'radius',radius,'epsilon',epsilon,'az',az,'el',el};

if ~isempty(col);farg=col;end
if ~isempty(thick);thickness=thick;end

%%%%% Fixing stuff related to holding the plot %%%%

initialhold=ishold;
if ~initialhold;clf;end
hold on

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%% The main function starts  %%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

w=width/2;
t=thickness/2;

perpa=cross(normal,up)/norm(cross(normal,up));
perpb=cross(perpa,normal)/norm(cross(perpa,normal));

perp11=perpa+perpb;
perp22=-perpa+perpb;
perp1=perp11/norm(perp11);    %A normalized vector along the first arm
perp2=perp22/norm(perp22);    %A normalized vector along the second arm

p1t(1,1,1:3)=t*perp1;
p1w(1,1,1:3)=w*perp1;
p2t(1,1,1:3)=t*perp2;
p2w(1,1,1:3)=w*perp2;

%%%% The cross coordinates, due to how Matlab divides
%%%% a surface into triangular surfaces we need to add
%%%% a few dummy-points (2:n and last second columns)

if isequal(crosstype,'plus')
    r=[ p1t-p2t   p1t-p2t  p1w-p2t     p1w+p2t   p1t+p2t  p1t+p2t;...
        p1t-p2w   p1t-p2t  p1t-p2t     p1t+p2t    p1t+p2t p1t+p2w;...
        -p1t-p2w  -p1t-p2t  -p1t-p2t    -p1t+p2t   -p1t+p2t -p1t+p2w;...
        -p1t-p2t   -p1t-p2t -p1w-p2t    -p1w+p2t   -p1t+p2t -p1t+p2t];
else
    r=[ p1t-p2t   p1t-p2t  p1w-p2t     p1w+p2t-2*p1t   p1t+p2t  p1t+p2t;...
        p1t-p2w   p1t-p2t  p1t-p2t     p1t+p2t    p1t+p2t   p1t+p2w-2*p2t;...
        -p1t-p2w+2*p2t  -p1t-p2t  -p1t-p2t    -p1t+p2t   -p1t+p2t -p1t+p2w;...
        -p1t-p2t   -p1t-p2t -p1w-p2t+2*p1t    -p1w+p2t   -p1t+p2t -p1t+p2t];
end

X=r(:,:,1)+x(1);
Y=r(:,:,2)+x(2);
Z=r(:,:,3)+x(3);

out=rjxsurf(X,Y,Z,ones(size(X)),'farg',farg,'settings',to_rjxsurf);
set(out,'EdgeColor','none');

if ~isempty(reflectionproperties)
    set(h3,reflectionproperties{:});
end
	

if initialhold==0;hold off;end














