function [out,surfset]=rjxsurfline(X,N,varargin)
%RJXSURFLINE(X,N,Options)
%
%The options, with default values are:
%
%     'farg',     [0 0 0];
%     'scale',    1;
%     'offset',   [0 0 0];
%     'mode',     1;
%     'az',       []
%     'el',       [];
%     'radius',   [];     
%     'epsilon',  0.01;
%     'startwidth',0.04;
%     'endwidth', 0.1;
%     'arrow',    'on';   %'off', 'curved'
%     'perpmode',  'off'
%     'extend',    0;       % 'on' or non-negative number
%     'startplanenormal', 'off';    % A normal vector
%     'endplanenormal', 'off'       % A normal vector
%     'relarrowlength', 1;          % The relative arrowlength

if rem(length(varargin),2)==1,
   error('RJ: Property value pairs expected.')
end  

default={
    'farg',     [0 0 0];
    'scale',    1;
    'offset',   [0 0 0];
    'mode',     1;
    'az',       []
    'el',       [];
    'radius',   [];     
    'epsilon',  0.01;
    'startwidth',0.04;
    'endwidth', 0.1;
    'arrow',    'on';
    'perpmode',  'off';
    'extend',    0;         % 'on' or non-negative number
    'startplanenormal', 'off';    % A normal vector
    'endplanenormal', 'off'       % A normal vector
    'relarrowlength', 1;          % The relative arrowlength
    'dashlength',[];              % Nonempty means dashed line
    'gapfactor',0.3;              % gaplength=gapfactor*dashlength
    'backextend',0;         % 'on', 'off' or non-negative number
    'cutlength', [];        % A proper length where to cut the line
    'width',[];             %Sets the width of the line to this
                            %constant; overrules startwidth and endwidth
    'col',[];               %Updated version; overrules 'farg'
    'transparency',     [];
    'reflectionproperties',[];
    'eyeset', [];           %{az,el,radius} radius=[] means infinity
    'setcylinder','off';       %makes a cylinder around the trajectory
    'ncylinder', 20;        %the number of sections around the cylinder
    'getvalues','off'       %'on' means setvalues={XX,YY,ZZ}
    'setsurf','on'          %'off' means turned off surface, but
                            %returning the correct values if getvalues is
                            %'on'
    'turnangle',0;          %cylinder turnangle
};

eval(setvalues);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if ~isempty(eyeset)
    az=eyeset{1};
    el=eyeset{2};
    radius=eyeset{3};
end


if isempty(width)
    st=startwidth;
    en=endwidth;
else
    st=width;
    en=width;
end

if ~isempty(col)
    farg=col;
end

if size(X,1)~=size(N,1)
    error('RJ: X and N different size');
end


to_rjxsurf={'scale',scale,'offset',offset,'mode',mode, ...
        'radius',radius,'epsilon',epsilon,'az',az,'el',el};

%%%%% Fixing stuff related to holding the plot %%%%

initialhold=ishold;
if ~initialhold;clf;end
hold on

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%% The main function starts  %%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

c=rjadd(farg);
normal=N;

%%%%%%%%%%% Delta vector along geodet %%%%%%%%%%%%

le=size(X,1);
if le<2
    error('RJ: Too short vector to rjxsurfline')
end

pointing=X(2:le,:)-X(1:le-1,:);

%%%% Cutting at a certain length, if such is given %%%%%

if ~isequal(cutlength,[])
    if cutlength>0
	tempdistance=rjnorm(pointing);             
	tempcumdistance=[0 cumsum(tempdistance)];
	if cutlength>tempcumdistance(le)   %Then make it longer
	    disp('Extending the line to cutlength')
	    extralength=cutlength-tempcumdistance(le);
	    lp=size(pointing,1);
	    lastpointing=pointing(lp,:);
	    extravector=lastpointing/norm(lastpointing)*extralength;
	    X=[X;X(le,:)+extravector];
	    normal=[normal;normal(le,:)];
	    le=size(X,1);
	    pointing=X(2:le,:)-X(1:le-1,:);
	else
	    tempi=decimalindex(cutlength,tempcumdistance);
	    X=cutsection(0,tempi,X);
	    normal=cutsection(0,tempi,normal);
	    le=size(X,1);
	    pointing=X(2:le,:)-X(1:le-1,:);
	end
	N=normal;
    else
	warning('RJ: Do you really want zero length')
	out=[];
	return
    end
end

%%%% Averaged deltavector, for nize perpvector %%%%%%%%

body=( X(3:le,:)-X(1:le-2,:) )/2;   %Is empty if le<3
first=X(2,:)-X(1,:);
last=X(le,:)-X(le-1,:);
avpointing=[first;body;last];
    
%%%%%%%%%% Extending the line %%%%%%%%%%%%%%%%%%%%%

if isequal(extend,'on')
    extend=1.5*en;
end

if isequal(extend,'off')
    extend=0;
end

if isequal(backextend,'on')
    backextend=1.5*en;
end

if isequal(backextend,'off')
    backextend=0;
end

if extend>0 | backextend>0
    
    %%% Forwardextend %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        
    if extend>0
	lastnormal=N(le,:);
	dvector=pointing(le-1,:);
	ds=norm(dvector);
	whole=floor(extend/ds);
	rest=extend-whole*ds;
	ext=zeros(whole+1,3);
	extnormal=zeros(whole+1,3);
	for ik=1:whole
	    ext(ik,:)=dvector*ik+X(le,:);
	    extnormal(ik,:)=lastnormal;
	end
	
	if whole~=0
	    ext(whole+1,:)=dvector*rest/ds+ext(whole,:);
	else
	    ext(whole+1,:)=dvector*rest/ds+X(le,:);
	end
	extnormal(whole+1,:)=lastnormal;
	X=[X;ext];
	N=[N;extnormal];
    end
    
    %%% Backextend %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    if backextend>0
	lastnormal=N(1,:);      %Should be firstnormal here
	dvector=-pointing(1,:);
	ds=norm(dvector);
	whole=floor(extend/ds);
	rest=backextend-whole*ds;
	ext=zeros(whole+1,3);       %Initializing
	extnormal=zeros(whole+1,3); %Initializing
	for ik=1:whole
	    ext(ik,:)=dvector*ik+X(1,:);
	    extnormal(ik,:)=lastnormal;
	end
	if whole~=0
	    ext(whole+1,:)=dvector*rest/ds+ext(whole,:);
	else
	    ext(whole+1,:)=dvector*rest/ds+X(1,:);
	end
	extnormal(whole+1,:)=lastnormal;
	X=[flipud(ext);X];
	N=[flipud(extnormal);N];
    end
    
    %%%%% Redoing the stuff from before  %%%%%%%%%%%%%
    
    normal=N;
    
    %%%%%%%%%%% Delta vector along geodet %%%%%%%%%%%%
    
    le=size(X,1);
    pointing=X(2:le,:)-X(1:le-1,:);
    
    %%%% Averaged deltavector, for perpvector %%%%%%%%
    
    body=( X(3:le,:)-X(1:le-2,:) )/2;
    first=X(2,:)-X(1,:);
    last=X(le,:)-X(le-1,:);
    avpointing=[first;body;last];
end

%%% Unit vector for width of geodet %%%%%%%%%%%%%%%

if isequal(perpmode,'off')
    perpvector=cross(normal,avpointing,2);
else
    perpvector=normal;
end

%%%%%%% Testing the normal vector %%%%%%%%%%%%%%%%%

if sum(perpvector==0)>0
    warning('RJ: The normal vector is parallel to the average pointing vector; Surface may not be complete')
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for i=1:le        %normalization is done later also?
    nperpvector(i,:)=perpvector(i,:)/norm(perpvector(i,:));
end

distance=rjnorm(pointing);
cumdistance=[0 cumsum(distance)];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%% The arrow %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if isequal(arrow,'curved')
    width=2*en;                       %The width of the arrow
    arrowlength=3*en*relarrowlength;  %The length of the arrow
    
    if arrowlength>cumdistance(length(cumdistance))
	warning('RJ: Arrowlength > linelength, decresing arrowlength')
	arrowlength=0.9*cumdistance(length(cumdistance))
    end
        
    %Adding two points where the arrowhead should start
    
    arrowdist=cumdistance(length(cumdistance))-arrowlength;
    reldistance=cumdistance-arrowdist;
    [mindist,i]=min(abs(reldistance));
    if cumdistance(i)<arrowdist   
        i1=i;
        i2=i+1;
    else
        i1=i-1;
        i2=i;
    end
    
    relative=(arrowdist-cumdistance(i1))/distance(i1);
    Xextra=(X(i2,:) - X(i1,:))*relative + X(i1,:);
    perpextra=(perpvector(i2,:) - perpvector(i1,:))*relative +...
	      perpvector(i1,:);
    X=[X(1:i1,:) ;Xextra; Xextra; X(i2:size(X,1),:)];
    perpvector=[perpvector(1:i1,:) ;perpextra; perpextra;...
		perpvector(i2:size(perpvector,1),:)];
    
    %%%%%% Setting the width of the line, including the arrow %%%%%%
    
    stemcumdistance=[cumdistance(1:i1) arrowdist];
    stemwidth=(en-st)*stemcumdistance/cumdistance(le)+st;
    tempvector=[arrowdist cumdistance(i2:length(cumdistance))];
    arrowwidth=width*(1  -  (tempvector - arrowdist)/arrowlength    );
    totalwidth=[stemwidth arrowwidth];
else
    %% Do not add elements to X, and perpvector
    totalwidth=cumdistance/cumdistance(length(cumdistance))*(en-st) + st;
end

%%%%%%%% Making the surface %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for i=1:size(perpvector,1)
    nperpvector(i,:)=perpvector(i,:)/norm(perpvector(i,:));
end

np1=nperpvector(:,1)'.*totalwidth*0.5;
np2=nperpvector(:,2)'.*totalwidth*0.5;
np3=nperpvector(:,3)'.*totalwidth*0.5;

xx=X(:,1)';
yy=X(:,2)';
zz=X(:,3)';

xx1=xx-np1;
yy1=yy-np2;
zz1=zz-np3;

xx2=xx+np1;
yy2=yy+np2;
zz2=zz+np3;

edgel=[xx1' yy1' zz1'];
middle=[xx' yy' zz'];
edger=[xx2' yy2' zz2'];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%% Make the beginning and the end of the line %%%%%%%%%%%%%
%%%%%%% respectively fit a plane of a given normal %%%%%%%%%%%%%

ni=0;
if ~isequal(startplanenormal,'off')
    ni=1;
    [edgel,edger]=fixend(edgel,middle,edger,startplanenormal);
end

nf=0;
if ~isequal(endplanenormal,'off')
    nf=1;
    [edgel,edger]=...
	fixend(flipud(edgel),flipud(middle),flipud(edger),endplanenormal);
    edgel=flipud(edgel);
    edger=flipud(edger);
end

%%%%%%%%%%%%%%%% The main plot %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

XX=[edgel(:,1) edger(:,1)];
YY=[edgel(:,2) edger(:,2)];
ZZ=[edgel(:,3) edger(:,3)];
CC=c*ones(size(ZZ));

if isequal(setcylinder,'on')
    npoint=rjnormalize(avpointing);
    base1=[np1',np2',np3'];
    base2=rjcross(npoint,base1);
    for i=0:ncylinder
	alpha=2*pi*i/ncylinder+turnangle/180*pi;
	pekvec=cos(alpha)*base1+sin(alpha)*base2;
	XX(:,i+1)=pekvec(:,1)+middle(:,1);
	YY(:,i+1)=pekvec(:,2)+middle(:,2);
	ZZ(:,i+1)=pekvec(:,3)+middle(:,3);
	CC=c*ones(size(ZZ));
    end
end

if isequal(getvalues,'on')
    surfset={XX,YY,ZZ};
else
    surfset={};
end

if isempty(dashlength) 
    if isequal(setsurf,'on')
	out1=rjxsurf(XX,YY,ZZ,CC,'settings',to_rjxsurf);
    else
	out1=[];
    end
end

%%%%%% Fixing a dashed line %%%%%%%%%%%%%%%%%%%

if ~isempty(dashlength)
    tempposition=[XX(:,1)+XX(:,2) , YY(:,1)+YY(:,2) , ZZ(:,1)+ZZ(:,2)]/2;
    lnew=size(tempposition,1);
    position=tempposition(1+ni:lnew-nf,:);
    cumdistance=rjdistance(position);
    maxdist=cumdistance(length(cumdistance));
    step=dashlength*(1+gapfactor);
    ns=floor(maxdist/step);
    newstep=maxdist/(ns+1/(1+gapfactor));
    newdashlength=newstep*1/(1+gapfactor);
    imax=ns;
    
    for i=0:imax;
	startdist=i*newstep;
	enddist=startdist+newdashlength;
	startindex=decimalindex(startdist,cumdistance);
	endindex=decimalindex(enddist,cumdistance);
		
	if i==0 & ni==1
	    n1=0;
	    n2=ni;
	elseif i==imax & nf==1
	    n1=ni;
	    n2=ni+1;
	else	
	    n1=ni;
	    n2=ni;
	end
	
	dashXX=cutsection(startindex+n1,endindex+n2,XX);
	dashYY=cutsection(startindex+n1,endindex+n2,YY);
	dashZZ=cutsection(startindex+n1,endindex+n2,ZZ);
	dashCC=c*ones(size(dashZZ));
	
	out1(i+1)=rjxsurf(dashXX,dashYY,dashZZ,dashCC,...
			'settings',to_rjxsurf);
    end
end

hold on
shading flat

%%%%%%%%%% Making a flat surface-arrow %%%%%%%%%%%%%%%%%

if isequal(arrow,'on')
    pl=size(pointing,1);
    [s1 s2]=size(perpvector);
    pperpvector=perpvector(s1,:)/norm(perpvector(s1,:));
    ppointing=pointing(pl,:)/norm(pointing(pl,:));
    position=[xx(s1),yy(s1),zz(s1)];
    width=2*en;              %The width of the arrow
    arrowlength=1/2*3*en;    %The length of the arrow
    offset=ppointing*arrowlength*0.05;
    tippoint=position+ppointing*arrowlength*0.85+offset;
    
    backleftpoint=position-arrowlength*ppointing+width/2*pperpvector+offset;
    backrightpoint=position-arrowlength*ppointing-width/2*pperpvector+offset;
    XXX=[backrightpoint(1) backleftpoint(1); tippoint(1) tippoint(1)];
    YYY=[backrightpoint(2) backleftpoint(2); tippoint(2) tippoint(2)];
    ZZZ=[backrightpoint(3) backleftpoint(3); tippoint(3) tippoint(3)];
    CCC=c*ones(size(ZZZ));
    out2=rjxsurf(XXX,YYY,ZZZ,CCC,'settings',to_rjxsurf);
    shading flat
    
    out=[out1 out2];
else
    out=out1;
end

if initialhold==0;hold off;end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if ~isempty(reflectionproperties)    %should do this in rjxsurfline
    set(out,reflectionproperties{:});
end

if ~isempty(transparency)            %should do this in rjxsurfline
    set(out,'FaceAlpha',transparency)
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%% Function fixend  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [edgel,edger]=fixend(edgel,middle,edger,planenormal)

snormal=planenormal/norm(planenormal);
edgelo=edgel;               %copy the original input
edgero=edger;               %copy the original input
pointing1=middle(2,:)-middle(1,:);
if dot(pointing1,snormal)<0
    snormal=-snormal;
end
shorten='on';
i=0;

if abs(cross(snormal,pointing1))==0
    return
end

while isequal(shorten,'on')
    i=i+1;
    hm=dot(  middle(i,:)-middle(1,:), snormal);
    hl=dot(  edgel(i,:)-middle(1,:) , snormal);
    hr=dot(  edger(i,:)-middle(1,:) , snormal);
    shorten='off';
    if hl<0
        shorten='on';
        if hm-hl==0
            frac=1;
        else
            frac=hm/(hm-hl);
        end
        ovec=edgel(i,:)-middle(i,:);
        nyvec=frac*ovec;
        nyedgel=middle(i,:)+nyvec;
        edgel(i,:)=nyedgel;
        last='l';
    elseif hr<0
        shorten='on';
        if hm-hr==0
            frac=1;
        else
            frac=hm/(hm-hr);
        end
        ovec=edger(i,:)-middle(i,:);
        nyvec=frac*ovec;
        nyedger=middle(i,:)+nyvec;
        edger(i,:)=nyedger;
        last='r';
    end 
    hmm(i,:)=hm;
    hll(i,:)=hl;
    hrr(i,:)=hr;
end

%%%%% Adding an extra point at the exact intersection %%%%%%%%%%%%%%%%%%%

if ~exist('last')
    last='r';
end


if isequal(last,'l');
    frac=-hll(i-1)/(hll(i,:)-hll(i-1,:));
    edgelny=(edgelo(i,:)-edgelo(i-1,:))*frac+edgelo(i-1,:);
    edgerny=(edgero(i,:)-edgero(i-1,:))*frac+edgero(i-1,:);
elseif isequal(last,'r');
    frac=-hrr(i-1,:)/(hrr(i,:)-hrr(i-1,:));
    edgelny=(edgelo(i,:)-edgelo(i-1,:))*frac+edgelo(i-1,:);
    edgerny=(edgero(i,:)-edgero(i-1,:))*frac+edgero(i-1,:);
end

edgel=[edgel(1:i-1,:);edgelny;edgel(i:size(edgel,1),:)];
edger=[edger(1:i-1,:);edgerny;edger(i:size(edger,1),:)];

%%%%%%%% Adding an extra triangel in the end %%%%%%%%%%%%%%%%%%%%%%%%%%%%

edgelny=[0 0 0];
edgerny=[0 0 0];

if hll(1)<0
    n1=normalize(middle(1,:)-middle(2,:));   
    v1=(edger(1,:)-middle(1,:));
    le=-dot(v1,snormal)/dot(n1,snormal);
    edgerny=edger(1,:)+n1*le;
    edgelny=middle(1,:);
elseif hrr(1)<0
    n1=normalize(middle(1,:)-middle(2,:));   
    v1=(edgel(1,:)-middle(1,:));
    le=-dot(v1,snormal)/dot(n1,snormal);
    edgelny=edgel(1,:)+n1*le;
    edgerny=middle(1,:);
end   

edgel=[edgelny;edgel];
edger=[edgerny;edger];














