function out=rotlightcone(rvec,zvec,a_base,phi_base,a_start,phi_start,conemode,msize,varargin)
%ROTLIGHTCONE
%
%  Produces three trajectories corresponding to the edges of a lightcone, 
%  on a rotational surface.

default={
    'number', 20;
    };
eval(setvalues);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

sizefactor=0.7;
maxlength=1.2*msize;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%% The light signals %%%%%%%%%%%%%%%%%%%%%%%%%%%

if conemode==1;mode1=1;mode2=2;end
if conemode==2;mode1=2;mode2=3;end
if conemode==3;mode1=3;mode2=4;end
if conemode==4;mode1=4;mode2=1;end

cell1=findphoton(rvec,zvec,a_base,phi_base,a_start,phi_start,mode1,maxlength,number);
cell2=findphoton(rvec,zvec,a_base,phi_base,a_start,phi_start,mode2,maxlength,number);

%out={cell1{1},cell1{2},cell2{1},cell2{2},[],[]};
%return

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%% The top of the cone %%%%%%%%%%%%%%%%%%%%%%%%

% Finding the length along the surface vector %%

lr=length(rvec);
dr=rvec(2:lr)-rvec(1:lr-1);
dz=zvec(2:lr)-zvec(1:lr-1);
dl=sqrt(dr.^2+dz.^2);
if size(dl,2)>size(dl,1)
     l_base=[0 cumsum(dl)];
else
     l_base=[0;cumsum(dl)];
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

distance=sizefactor*msize;
l_start=findvalue(a_start,a_base,l_base);
rvertex=findvalue(a_start,a_base,rvec);

if conemode==1;k=1;end
if conemode==2;k=-1;end
if conemode==3;k=-1;end
if conemode==4;k=1;end

factor=2;    %Making the top line longer

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Assuming the lightcone to open up in the azimuthal direction.  %%%%%%%

if conemode==2 | conemode==4 
     r=findvalue(a_start,a_base,rvec);
     deltaphi=distance/r;
     phitopstart=phi_start+deltaphi*k;
     a_topend1=findvalue(l_start+maxlength,l_base,a_base);
     a_topend2=findvalue(l_start-maxlength,l_base,a_base);
     a_topvec=linspace(a_topend1,a_topend2,number);
     phi_topvec=phitopstart*ones(size(a_topvec));
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Assuming the lightcone to open up along the rotational surface %%%%%%%

if conemode==1 | conemode==3
     r_topstart=findvalue(l_start+k*distance,l_base,rvec);
     deltaphi=distance/min(r_topstart,rvertex)*factor;
     a_topstart=findvalue(l_start+k*distance,l_base,a_base);
     phi_topvec=linspace(phi_start-deltaphi, phi_start+deltaphi,number);
     a_topvec=a_topstart*ones(size(phi_topvec));
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

out={cell1{1},cell1{2},cell2{1},cell2{2},phi_topvec,a_topvec};













