function out=rotminkowski(X,Y,Z,a_base,phi_base,a_start,phi_start,conemode,msize,varargin)
%
% ROTMINKOWSKI(X,Y,Z,a_base,phi_base,a_start,phi_start,conemode,msize,OPTIONS)
%   The purpose of this function is ultimately to produce local Minkowski
%   systems living on rotational surfaces in the absolute scheme.
%   Given a starting point on the parametrized rotational surface,
%   rotminkowski returns three coordinate lines, corresponding to one
%   time axis and two (one left and one right) spatial axes. The proper
%   length of the timeaxis line is equal to msize. The proper
%   length of the spatial axes is equal to msize times a factor (0.75).
%   The direction of the system is either exactly azimuthal (pos or neg),
%   or along (pos or neg). The output is in the form
%   {avec1,phivec1,avec2,phivec2,avec3,phivec3} where 1 corresponds to the time axis,
%   and 2 and 3 are the spatial axes.

default={
	'number',10;          %The number of points in the lines
        'spacefactor', 0.75;  %
	};

eval(setvalues)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

N=number;

if conemode==1;codirset={'a_pos','phi_pos','phi_neg'};end
if conemode==4;codirset={'phi_pos','a_neg','a_pos'};end
if conemode==3;codirset={'a_neg','phi_neg','phi_pos'};end
if conemode==2;codirset={'phi_neg','a_pos','a_neg'};end

dirlengthset={msize,msize*spacefactor,msize*spacefactor};

for i=1:3
    codir=codirset{i};
    dirlength=dirlengthset{i};
    if isequal(codir,'a_pos') | isequal(codir,'phi_pos');
	k=1;
    else;
	k=-1;
    end
        
    if isequal(codir,'a_pos') | isequal(codir,'a_neg')
	totdist=distonsurf(X,Y,Z,a_base,phi_base,a_base,phi_start*ones(size(a_base)));
	
	dist1=findvalue(a_start,a_base,totdist);
	dist2=dist1+dirlength*k;
	
	a1=findvalue(dist1,totdist,a_base);
	a2=findvalue(dist2,totdist,a_base);
	
	avec=linspace(a1,a2,N);
	phivec=phi_start*ones(size(avec));
    end
    
    if isequal(codir,'phi_pos') | isequal(codir,'phi_neg')
	totdist=distonsurf(X,Y,Z,a_base,phi_base,a_start*ones(size(phi_base)),phi_base);
	
	dist1=findvalue(phi_start,phi_base,totdist);
	dist2=dist1+dirlength*k;
	
	phi1=findvalue(dist1,totdist,phi_base);
	phi2=findvalue(dist2,totdist,phi_base);
	
	phivec=linspace(phi1,phi2,N);
	avec=a_start*ones(size(phivec));
    end
    
    out{i*2-1}=avec;
    out{i*2}=phivec;
end










