function h=surfonsurf(X,Y,Z,base1,base2,xmatrix,ymatrix,varargin)
%SURFONSURF(X,Y,Z,base1,base2,xmatrix,ymatrix,eyeset,OPTIONS)
% Adds a surface on top of (part of) an already existing surface.
% X,Y and Z are the position matrices for the background surface. 
%
% base1 and base2 are vectors describing the parameter values of the
% surface nodes. base1 must have the same number of elements as there
% are rows in X and Y
%
% xmatrix and ymatrix are the coordinates of the surface to be put on
% top. xmatrix must have the same size as ymatrix.
%
% OPTIONS are of the type 'parameter', value, 'parameter',
% value ... What parameters that can be set depends on rjxsurf

if size(X,1)~=length(base1)
    error('RJ: No of elements in base1 not corresponding to no of rows in X')
end

if size(X,2)~=length(base2)
    error('RJ: No of elements in base2 not corresponding to no of columns in X')
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%% The real stuff starts here %%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Xs=[];
Ys=[];
Zs=[];

for i=1:size(xmatrix,1)
    
    x=xmatrix(i,:);
    y=ymatrix(i,:);
    le=length(x);
    rjempty=0;
    
    edgecut='off';
    if isequal(edgecut,'on')
	[x y]=cutthecrap(base1,base2,x,y);
	if isempty(x) | isempty (y)
	    rjempty=1;
	end
	
	%% A first attempt at proper cutting
	%% Assuming the cutting to be at the 'rightmost' end
	%% It will be uggly if it aint though :)
	
	x=[x x(length(x))*zeros(1,le-length(x))]; %Adding dummy elements if necessary
	y=[y y(length(y))*zeros(1,le-length(y))]; %Adding dummy elements if necessary
    end
    
    %%%%%%%%%%% Finding positions %%%%%%%%%%%%%
    
    position=zeros(length(x),3);           %Initializing
  
    for nr=1:length(x);
	i=decimalindex(x(nr),base1);
	j=decimalindex(y(nr),base2);
	position(nr,:)=rjfinddecimalposition(i,j,X,Y,Z);
    end
    
    Xs=[Xs position(:,1)];
    Ys=[Ys position(:,2)];
    Zs=[Zs position(:,3)];
    
end
    
h=rjxsurf(Xs,Ys,Zs,ones(size(Xs)),varargin{:});








