function out=transition(r,a,m)
%'r' is a vector or matrix, that is assumed to be normalized to range [0 1].
%'a' is a transition position in the range [0 1],
%'m' is a measure of the rapidness of the transition. 'm' should be greater
%than one and typically smaller than 100. Transition returns a vector or
%matrix that has the same size as 'r' and that has the values of the
%transition function.
%
%What transition does is that it connects two powerfunctions at the point
%x=a, such that the derivative is continuous. Also the powerfunctions
%have zero derivative at the borders.

if a>0.5
    b=m/2/(1-a);
    n=m*a/(1-a);
else
    n=m;
    m=n*(1-a)/a;
end

%r=r/(max(max(r)));
f=zeros(size(r));

for i=1:size(r,1)
    for j=1:size(r,2)
	if r(i,j)<a 
	    x1=r(i,j);
	    f(i,j)=1-1/2*(x1/a).^n;
	else
	    x2=r(i,j);
	    f(i,j)=1/2*( (1-x2)/(1-a) ).^m;
	end
    end
end

out=f;





