function [xmatrix,ymatrix]=trianglegrid(xvec1,yvec1,xvec2,yvec2,xvec3,yvec3)
%[xmatrix,ymatrix]=TRIANGLEGRID(xvec1,yvec1,xvec2,yvec2,xvec3,yvec3)
%
% Given three 2D lines (1,2,3) trianglegrid calculates x and y matrixes -
% corresponding to the interior of the triangle that
% is spanned by the three lines. Line 1 and 2 are assumed to have the
% exact same starting point. Line 3 is assumed to intersect line 1 at
% exactly one point. Line 3 is also assumed to intersect line 2 at
% exactly one point. 
%
% The resolution of the triangle along the time axis is determined by
% that of line 1 and 2 that has the lowest resolution. Also - after
% cutting these lines to the proper length they are resampled. For very
% low resolution lines - the resulting triangle may therefore not fill
% exactly the space spanned by the three lines. The solution is to
% increase the resolution (more points) in the lines

[i1,i2a]=curveintersection(xvec1,yvec1,xvec3,yvec3);

if isempty(i1) | isempty(i2a)
    error('RJ: curves not intersecting')
end

xvec1=cut(i1,xvec1);
yvec1=cut(i1,yvec1);

[i1,i2b]=curveintersection(xvec2,yvec2,xvec3,yvec3);

if isempty(i1) | isempty(i2b)
    error('RJ: curves not intersecting')
end

xvec2=cut(i1,xvec2);
yvec2=cut(i1,yvec2);

xvec3=cutsection(min(i2a,i2b),max(i2a,i2b),xvec3')';
yvec3=cutsection(min(i2a,i2b),max(i2a,i2b),yvec3')';

temp1=length(xvec1);
temp2=length(xvec2);
nmin=min(temp1,temp2);
nmax=max(temp1,temp2);

[xvec1,yvec1]=rjresample(xvec1,yvec1,nmax);
[xvec2,yvec2]=rjresample(xvec2,yvec2,nmax);

%%% Expressing the relative positions of the top line vector in a new base %%

deltax=xvec3-xvec3(1);
deltay=yvec3-yvec3(1);
le=length(deltax);
deltar=[deltax' deltay'];
dr=deltar(le,:);
drlength=norm(dr);
n1=dr/norm(dr); %One new normed base vector
n2temp=cross([0 0 1],[n1 0]);
n2=n2temp(1:2);                     %The other new normed base vector
delta1=deltar*n1';                  %The distance in the n1 direction, a column vector
delta2=rjnorm(deltar-delta1*n1)';    %The distance in the n2direction,acolumn vector

%%%% Extending the top line down into the triangle in a smooth manner %%%%%%%%%%%%

maxrow=length(xvec1);

for i=1:maxrow;
    drnew=[xvec2(i) yvec2(i)] - [xvec1(i) yvec1(i)];
    drlengthnew=norm(drnew);
    factor=drlengthnew/drlength;   %The scale factor
    if norm(drnew)==0
	n1new=[0 1];  %Just a dummy direction
    else
	n1new=drnew/norm(drnew);
    end
    n2temp=cross([0 0 1],[n1new 0]);               
    n2new=n2temp(1:2);
    deltarnew=(delta1*n1new+delta2*n2new)*factor;
    xmatrix(i,:)=xvec1(i)+deltarnew(:,1)';
    ymatrix(i,:)=yvec1(i)+deltarnew(:,2)';
end










